@@ -19,7 +19,7 @@
 
 package FindBin::libs;
 
-use v5.10;
+use v5.14;
 use strict;
 
 use FindBin;
@@ -64,21 +64,24 @@ BEGIN
         eval { $abs->( '//' );  $abs->( cwd ); 1 }
     )
     {
+        # nothing more to do: abs_path works.
     }
     elsif
     (
-        $abs = Cwd->can( 'rel2abs'  )
+        $abs = File::Spec::Functions->can( 'rel2abs'  )
     )
     {
         # ok, we have a substitute
     }
     else
     {
-        die "Cwd fails abs_path test && lacks 'rel2abs'\n";
+        die "Non-working abs_path without 'rel2abs'\n";
     }
 
     my $ref = *{ qualify_to_ref 'abs_path', __PACKAGE__ };
 
+    undef &{ *$ref };
+
     *{ $ref } = $abs;
 }
 
@@ -86,7 +89,7 @@ BEGIN
 # package variables 
 ########################################################################
 
-our $VERSION = v1.64.1;
+our $VERSION = v2.0.0;
 
 my %defaultz = 
 (
@@ -670,7 +673,7 @@ having to modify a single line of code.
 Say your sandbox is in ./sandbox and you are currently
 working in ./sandbox/projects/package/bin on a perl
 executable. You may have some number of modules that
-are specific -- or customized -- for this pacakge, 
+are specific -- or customized -- for this package, 
 share some modules within the project, and may want 
 to use company-wide modules that are managed out of 
 ./sandbox in development. All of this lives under a 
